@@ -3,7 +3,7 @@ package Set::Similarity::BV;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Carp 'croak';
 
@@ -20,8 +20,8 @@ sub similarity {
   return 1 if (!($hex1 || $hex2));    # both zero
   return 0 unless ($hex1 && $hex2);   # one is zero
 
-  return 1 if (!(hex($hex1) || hex($hex2)));    # both zero
-  return 0 unless (hex($hex1) && hex($hex2) ); # one is zero
+  #return 1 if (!(hex($hex1) || hex($hex2)));    # both zero
+  #return 0 unless (hex($hex1) && hex($hex2) ); # one is zero
 
   return $self->from_integers(
     hex($hex1),
@@ -155,6 +155,12 @@ Croaks if called directly. This method should be implemented in a child module.
 
   my $min = $object->min($int1,$int2);
 
+=head2 bits
+
+  my $bits = $object->bits($int);
+
+Returns the number of bits set in integer.
+
 
 =head1 SEE ALSO
 
